<?php
declare(strict_types = 1);

require_once(__DIR__ . '/Admin.class.php');

/**
 * Gestion des appareils photos.
 *
 * @license http://www.gnu.org/licenses/gpl.html
 * @link http://www.igalerie.org/
 */
class AdminCameras extends Admin
{
	/**
	 * Actions sur la sélection.
	 *
	 * @return void
	 */
	public static function actions(): void
	{
		switch (self::_getSelectedIds($selected_ids))
		{
			case 'delete' :
				$type = substr($_GET['section'], 8, -1);
				$r = Cameras::delete($type, $selected_ids);
				if ($r < 0)
				{
					Report::error();
				}
				else if ($r < 1)
				{
					Report::info($type == 'brand'
						? __('Aucune marque n\'a été supprimée.')
						: __('Aucun modèle n\'a été supprimé.'));
				}
				else
				{
					if ($type == 'brand')
					{
						Report::success($r > 1
							? sprintf(__('%s marques ont été supprimées.'), $r)
							: __('1 marque a été supprimée.'));
					}
					else
					{
						Report::success($r > 1
							? sprintf(__('%s modèles ont été supprimés.'), $r)
							: __('1 modèle a été supprimé.'));
					}
				}
				break;
		}
	}

	/**
	 * Édition des informations.
	 *
	 * @return void
	 */
	public static function edit(): void
	{
		if (!isset($_POST['cameras']) || !isset($_POST['save']))
		{
			return;
		}

		$type = substr($_GET['section'], 8, -1);
		$r = Cameras::edit($type, $_POST['cameras']);
		if ($r < 0)
		{
			Report::error();
		}
		else if ($r < 1)
		{
			Report::info($type == 'brand'
				? __('Aucune marque n\'a été modifiée.')
				: __('Aucun modèle n\'a été modifié.'));
		}
		else
		{
			if ($type == 'brand')
			{
				Report::success($r > 1
					? sprintf(__('%s marques ont été modifiées.'), $r)
					: __('1 marque a été modifiée.'));
			}
			else
			{
				Report::success($r > 1
					? sprintf(__('%s modèles ont été modifiés.'), $r)
					: __('1 modèle a été modifié.'));
			}
		}
	}

	/**
	 * Récupération des marques.
	 *
	 * @return void
	 */
	public static function getBrands(): void
	{
		// Fil d'Ariane.
		$breadcrumb = [
			[
				'current' => TRUE,
				'name' => __('Marques d\'appareils photos'),
				'url' => App::getURL($_GET['q_pageless'])
			]
		];
		Template::set('breadcrumb', $breadcrumb);
		Template::set('objects_count', 0);
		Template::set('cameras', []);

		
	}

	/**
	 * Récupération des modèles.
	 *
	 * @return void
	 */
	public static function getCameras(): void
	{
		$type = substr($_GET['section'], 8, -1);

		// Fil d'Ariane.
		$breadcrumb =
		[
			[
				'current' => TRUE,
				'name' => $type == 'brand'
					? __('Marques d\'appareils photos')
					: __('Modèles d\'appareils photos'),
				'url' => App::getURL($_GET['q_pageless'])
			]
		];
		Template::set('breadcrumb', $breadcrumb);
		Template::set('objects_count', 0);
		Template::set('cameras', []);

		// Nombre d'objets par page.
		$nb_per_page = Auth::$infos['user_prefs']['cameras_' . $type . 's']['nb_per_page'];

		// Clause WHERE.
		self::_sqlWhere($sql_where, $params);

		// Nombre d'objets.
		$sql = "SELECT COUNT(*) FROM {cameras_" . $type . "s} WHERE $sql_where";
		if (!DB::execute($sql, $params))
		{
			return;
		}
		Template::set('objects_count', $nb_cameras = DB::fetchVal());

		// Nombre de pages.
		Template::set('nb_pages', ceil($nb_cameras / $nb_per_page));
		$sql_limit_start = $nb_per_page * ($_GET['page'] - 1);

		// Critère de tri.
		$sql_order_by
			= Auth::$infos['user_prefs']['cameras_' . $type . 's']['order_by_column'];
		$sql_order_by_order
			= Auth::$infos['user_prefs']['cameras_' . $type . 's']['order_by_order'];

		// Récupération des objets.
		$sql_from = $type == 'brand'
			? 'LEFT JOIN {cameras_models} USING (camera_brand_id)'
			: '';
		$sql = "SELECT camera_{type}_id AS id,
					   camera_{type}_name AS name,
					   camera_{type}_url AS url,
					   COUNT(ci.item_id) AS camera_{type}_count
				  FROM {cameras_{type}s}
					   $sql_from
			 LEFT JOIN {cameras_items} AS ci USING (camera_model_id)
				 WHERE $sql_where
			  GROUP BY camera_{type}_id
			  ORDER BY camera_{type}_$sql_order_by $sql_order_by_order
			     LIMIT $sql_limit_start,$nb_per_page";
		$sql = str_replace('{type}', $type, $sql);
		if (!DB::execute($sql, $params))
		{
			return;
		}
		$cameras = DB::fetchAll();
		if (!self::_objectsNoResult(count($cameras)))
		{
			return;
		}

		// Formatage des données.
		$cameras_formated = [];
		foreach ($cameras as &$i)
		{
			$cameras_formated[] =
			[
				'count' => $i['camera_' . $type . '_count'],
				'id' => $i['id'],
				'link' => $i['camera_' . $type . '_count'] > 0
					? App::getURL('category/1/camera-' . $type . '/' . $i['id'])
					: NULL,
				'name' => $i['name'],
				'url' => $i['url']
			];
		}
		Template::set('cameras', $cameras_formated);

		
	}

	/**
	 * Informations de template pour le moteur de recherche.
	 *
	 * @param array $functions
	 *
	 * @return void
	 */
	public static function tplSearch(array &$functions): void
	{
		Template::set('search', ['columns' => $functions['columns'](
		[
			'camera_brand_name' => TRUE,
			'camera_brand_url' => TRUE,
			'camera_model_name' => TRUE,
			'camera_model_url' => TRUE
		])]);
	}



	/**
	 * Clause WHERE d'une requête SQL.
	 *
	 * @param mixed $sql
	 * @param mixed $params
	 *
	 * @return void
	 */
	private static function _sqlWhere(&$sql, &$params): void
	{
		$sql = '1=1';
		$params = [];
		switch ($_GET['filter'] ?? '')
		{
			case 'search' :
				if (!$search = self::$search->sql())
				{
					App::redirect($_GET['q_filterless']);
				}
				$sql = $search['sql'];
				$params = $search['params'];
				break;
		}
	}
}
?>